@@ -341,7 +341,7 @@ class Cases:
                     if case_id:
                         # 创建测试计划和测试用例关联关系, 已关联过的用例不重复关联
                         test_plan_id = test_plans_map.get(self.case_ws[story_cell].value)
-                        if test_plan_id and not self.case_ws[case_id_cell].value:
+                        if test_plan_id:
                             self.excel.tapd.post_tapd_test_plans_and_tcase_relation(
                                 test_plan_id=test_plan_id,
                                 tcase_ids=case_id,
